@@ -209,7 +209,8 @@ class FlamingoPaLM(nn.Module):
         cross_attn_every=3,
         img_encoder=None,
         perceiver_num_latents=64,
-        perceiver_depth=2
+        perceiver_depth=2,
+        only_attend_immediate_media=True
     ):
         super().__init__()
 
@@ -231,7 +232,7 @@ class FlamingoPaLM(nn.Module):
         for ind in range(depth):
             self.layers.append(nn.ModuleList([
                 Residual(ParallelTransformerBlock(dim=dim, dim_head=dim_head, heads=heads, ff_mult=ff_mult)),
-                GatedCrossAttentionBlock(dim=dim, dim_head=dim_head, heads=heads) if not (ind % cross_attn_every) else None
+                GatedCrossAttentionBlock(dim=dim, dim_head=dim_head, heads=heads, only_attend_immediate_media=only_attend_immediate_media) if not (ind % cross_attn_every) else None
             ]))
 
         self.to_logits = nn.Sequential(
