@@ -80,12 +80,12 @@ class PerceiverResampler(nn.Module):
         dim_head = 64,
         heads = 8,
         num_latents = 64,
-        num_time_embeds = 4,
+        num_media_embeds = 4,
         ff_mult = 4
     ):
         super().__init__()
         self.latents = nn.Parameter(torch.randn(num_latents, dim))
-        self.time_pos_emb = nn.Parameter(torch.randn(num_time_embeds, 1, dim))
+        self.media_pos_emb = nn.Parameter(torch.randn(num_media_embeds, 1, dim))
 
         self.layers = nn.ModuleList([])
         for _ in range(depth):
@@ -101,7 +101,7 @@ class PerceiverResampler(nn.Module):
             x = rearrange(x, 'b n d -> b 1 n d')
 
         times = x.shape[1]
-        x = x + self.time_pos_emb[:times]
+        x = x + self.media_pos_emb[:times]
 
         latents = repeat(self.latents, 'n d -> b m n d', b = x.shape[0], m = x.shape[1])
 
@@ -172,6 +172,12 @@ class MaskedCrossAttention(nn.Module):
         sim = sim - sim.amax(dim = -1, keepdim = True).detach()
         attn = sim.softmax(dim = -1)
 
+        if exists(media_locations) and self.only_attend_immediate_media:
+            # any text without a preceding media needs to have attention zeroed out
+            text_without_media_mask = text_time == 0
+            text_without_media_mask = rearrange(text_without_media_mask, 'b i -> b 1 i 1')
+            attn.masked_fill(text_without_media_mask, 0.)
+
         out = einsum('... i j, ... j d -> ... i d', attn, v)
         out = rearrange(out, 'b h n d -> b n (h d)')
         return self.to_out(out)
